==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ResponsiveStateEnteredEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteredEventArgsDescription } from "./ResponsiveStateEnteredEventArgsDescription";
/**
 * @hidden
 */
export let ResponsiveStateEnteredEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsiveStateEnteredEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsiveStateEnteredEventArgsDescriptionMetadata.a == null) {
                ResponsiveStateEnteredEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsiveStateEnteredEventArgsDescriptionMetadata.c(ResponsiveStateEnteredEventArgsDescriptionMetadata.a);
            }
            if (a.k(ResponsiveStateEnteredEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ResponsiveStateEnteredEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ResponsiveStateEnteredEventArgsDescriptionMetadata.b(a);
            a.ac("ResponsiveStateEnteredEventArgs", () => new ResponsiveStateEnteredEventArgsDescription());
            a.ab("ResponsiveStateEnteredEventArgs", ResponsiveStateEnteredEventArgsDescriptionMetadata.a);
        }
    }
    ResponsiveStateEnteredEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsiveStateEnteredEventArgsDescriptionMetadata, 'ResponsiveStateEnteredEventArgsDescriptionMetadata');
    ResponsiveStateEnteredEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteredEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ResponsiveStateEnteredEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteredEventArgsDescription } from "./ResponsiveStateEnteredEventArgsDescription";
/**
 * @hidden
 */
export let ResponsiveStateEnteredEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsiveStateEnteredEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsiveStateEnteredEventArgsDescriptionMetadata.a == null) {
                ResponsiveStateEnteredEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsiveStateEnteredEventArgsDescriptionMetadata.c(ResponsiveStateEnteredEventArgsDescriptionMetadata.a);
            }
            if (a.k(ResponsiveStateEnteredEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ResponsiveStateEnteredEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ResponsiveStateEnteredEventArgsDescriptionMetadata.b(a);
            a.ae("ResponsiveStateEnteredEventArgs", () => new ResponsiveStateEnteredEventArgsDescription());
            a.ad("ResponsiveStateEnteredEventArgs", ResponsiveStateEnteredEventArgsDescriptionMetadata.a);
        }
    }
    ResponsiveStateEnteredEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsiveStateEnteredEventArgsDescriptionMetadata, 'ResponsiveStateEnteredEventArgsDescriptionMetadata');
    ResponsiveStateEnteredEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteredEventArgsDescriptionMetadata;
})();
